# clienBBS ver 1.00

## 알림

오랫만에 해보니
이런저런 안되는게 많아 많이 고쳣습니다.
글 제목이 보이지 않는 버그를 수정했습니다.
첨부 사진, 영상의 링크를 글에 표시합니다.

## 설치

* Python 3 최신버전을 설치하여 주십시오.
* https://www.python.org/download/releases/3.6/
* 윈도우에서 pip 가 안되거나 문제가 발생하시면 http://wlsufld.tistory.com/17 를 참고해주세요 

## 쉬운 설치
```sh
pip install clienBBS
(안되면 pip3 install clienBBS)

```

## 혹은

이 저장소를 클론하시거나 다운로드하신 후,

```sh
pip install -e .
```

를 실행해주세요.

## 실행

* 폰트는 무료폰트인 D2Coding을 추천드립니다.
* 터미널에서 `clien` 명령으로 실행해주시면 됩니다.
* 터미널에서 실행되므로 터미널 색상을 잘 조정해주세요.
* 좋은 테마 세팅이 있으시면 공유해주세요!!!
* macOS에서는 첨부된 `set_colors_bw.sh` 또는 `set_colors_gb.sh`을 
  터미널에서 실행하시면, 색상을 쉽게 바꾸실 수 있습니다.

## 부탁

* 갑자기 떠오른 생각을 실현한거라 버그가 많을 수 있습니다
* 재밌게 사용하셨으면 저의 유튜브 채널이나 블로그에 오셔서 피드백 주세요

## 라이센스

* 개인적 용도의 소스코드 분석이나 변경 및 사용은 허용하지만,
* 상업적 용도의 사용이나 수정후 재배포는 불가함을 알려드립니다. 

## 링크

* 개발자: 매트 (johnleespapa@gmail.com)
* 유튜브 채널 http://youtube.com/leesinusa
* 블로그 http://leesintheusa.com
* 인스타그램 papamattlee
